# Michigan.Ods.Sdk.Composites.Transportation.TransportationStudentsApi

All URIs are relative to *https://api-mi.doubleline.us:443/ods-pd3/composites/v1/2023*

Method | HTTP request | Description
------------- | ------------- | -------------
[**GetTransportationStudents**](TransportationStudentsApi.md#gettransportationstudents) | **GET** /ed-fi/transportation/TransportationStudents | Retrieves specific resources using the resource&#39;s property values (using the \&quot;Get\&quot; pattern).
[**GetTransportationStudentsById**](TransportationStudentsApi.md#gettransportationstudentsbyid) | **GET** /ed-fi/transportation/TransportationStudents/{id} | Retrieves a specific resource using the resource&#39;s identifier (using the \&quot;Get By Id\&quot; pattern).


<a name="gettransportationstudents"></a>
# **GetTransportationStudents**
> List<TransportationStudent> GetTransportationStudents (int? offset = null, int? limit = null, int? minChangeVersion = null, int? maxChangeVersion = null, string fields = null, string q = null)

Retrieves specific resources using the resource's property values (using the \"Get\" pattern).

This GET operation provides access to resources using the \"Get\" search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Composites.Transportation;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Composites.Transportation;

namespace Example
{
    public class GetTransportationStudentsExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TransportationStudentsApi();
            var offset = 56;  // int? | Indicates how many items should be skipped before returning results. (optional)  (default to 0)
            var limit = 56;  // int? | Indicates the maximum number of items that should be returned in the results. (optional)  (default to 25)
            var minChangeVersion = 56;  // int? | Used in synchronization to set sequence minimum ChangeVersion (optional) 
            var maxChangeVersion = 56;  // int? | Used in synchronization to set sequence maximum ChangeVersion (optional) 
            var fields = fields_example;  // string | Specifies a subset of properties that should be returned for each entity (e.g. \"property1,collection1(collProp1,collProp2)\"). (optional) 
            var q = q_example;  // string | Specifies a query filter expression for the request. Currently only supports range-based queries on dates and numbers (e.g. \"[2016-03-07..2016-03-10]\"). (optional) 

            try
            {
                // Retrieves specific resources using the resource's property values (using the \"Get\" pattern).
                List&lt;TransportationStudent&gt; result = apiInstance.GetTransportationStudents(offset, limit, minChangeVersion, maxChangeVersion, fields, q);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TransportationStudentsApi.GetTransportationStudents: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **offset** | **int?**| Indicates how many items should be skipped before returning results. | [optional] [default to 0]
 **limit** | **int?**| Indicates the maximum number of items that should be returned in the results. | [optional] [default to 25]
 **minChangeVersion** | **int?**| Used in synchronization to set sequence minimum ChangeVersion | [optional] 
 **maxChangeVersion** | **int?**| Used in synchronization to set sequence maximum ChangeVersion | [optional] 
 **fields** | **string**| Specifies a subset of properties that should be returned for each entity (e.g. \&quot;property1,collection1(collProp1,collProp2)\&quot;). | [optional] 
 **q** | **string**| Specifies a query filter expression for the request. Currently only supports range-based queries on dates and numbers (e.g. \&quot;[2016-03-07..2016-03-10]\&quot;). | [optional] 

### Return type

[**List<TransportationStudent>**](TransportationStudent.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="gettransportationstudentsbyid"></a>
# **GetTransportationStudentsById**
> TransportationStudent GetTransportationStudentsById (string id, string ifNoneMatch = null, string fields = null)

Retrieves a specific resource using the resource's identifier (using the \"Get By Id\" pattern).

This GET operation retrieves a resource by the specified resource identifier.

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Composites.Transportation;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Composites.Transportation;

namespace Example
{
    public class GetTransportationStudentsByIdExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TransportationStudentsApi();
            var id = id_example;  // string | A resource identifier that uniquely identifies the resource.
            var ifNoneMatch = ifNoneMatch_example;  // string | The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource. (optional) 
            var fields = fields_example;  // string | Specifies a subset of properties that should be returned for each entity (e.g. \"property1,collection1(collProp1,collProp2)\"). (optional) 

            try
            {
                // Retrieves a specific resource using the resource's identifier (using the \"Get By Id\" pattern).
                TransportationStudent result = apiInstance.GetTransportationStudentsById(id, ifNoneMatch, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TransportationStudentsApi.GetTransportationStudentsById: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| A resource identifier that uniquely identifies the resource. | 
 **ifNoneMatch** | **string**| The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource. | [optional] 
 **fields** | **string**| Specifies a subset of properties that should be returned for each entity (e.g. \&quot;property1,collection1(collProp1,collProp2)\&quot;). | [optional] 

### Return type

[**TransportationStudent**](TransportationStudent.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

